==> igniteui-react-charts-18.6.0.tgz: package/esm2015/lib/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AverageTrueRangeIndicator = /*@__PURE__*/ (() => {
    class AverageTrueRangeIndicator extends StrategyBasedIndicator {
        bc() {
            return new AverageTrueRangeIndicator();
        }
        get_y0() {
            return new AverageTrueRangeIndicatorStrategy();
        }
        get y0() {
            return this.get_y0();
        }
        get_zd() {
            return AverageTrueRangeIndicator.$;
        }
        get zd() {
            return this.get_zd();
        }
        get zl() {
            return typeGetValue(this.c(AverageTrueRangeIndicator.zm));
        }
        set zl(a) {
            this.h(AverageTrueRangeIndicator.zm, a);
        }
        y6() {
            return this.zl;
        }
        zf(a) {
            this.zl = a;
        }
    }
    AverageTrueRangeIndicator.$t = /*@__PURE__*/ markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
    AverageTrueRangeIndicator.zm = /*@__PURE__*/ StrategyBasedIndicator.zi(14, AverageTrueRangeIndicator.$);
    return AverageTrueRangeIndicator;
})();

==> igniteui-react-charts-18.7.2.tgz: package/esm2015/lib/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AverageTrueRangeIndicator = /*@__PURE__*/ (() => {
    class AverageTrueRangeIndicator extends StrategyBasedIndicator {
        bi() {
            return new AverageTrueRangeIndicator();
        }
        get_abn() {
            return new AverageTrueRangeIndicatorStrategy();
        }
        get abn() {
            return this.get_abn();
        }
        get_ab0() {
            return AverageTrueRangeIndicator.$;
        }
        get ab0() {
            return this.get_ab0();
        }
        get ab8() {
            return typeGetValue(this.c(AverageTrueRangeIndicator.ab9));
        }
        set ab8(a) {
            this.h(AverageTrueRangeIndicator.ab9, a);
        }
        abt() {
            return this.ab8;
        }
        ab2(a) {
            this.ab8 = a;
        }
    }
    AverageTrueRangeIndicator.$t = /*@__PURE__*/ markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
    AverageTrueRangeIndicator.ab9 = /*@__PURE__*/ StrategyBasedIndicator.ab5(14, AverageTrueRangeIndicator.$);
    return AverageTrueRangeIndicator;
})();
